@@ -1666,3 +1666,77 @@ test_that("loops8", {
   
 })
 
+test_that("dplyr-apply", {
+  clamp_vectorized1a <- function(x) {
+    lapply(x, function(y) {
+      if (max(y)-min(y) < 1e-5) {
+        {{{{NULL}}}}
+      } else {
+        {{{{(y - min(y))/(max(y)-min(y))}}}}
+      }
+    })
+  }
+  
+  
+  
+  clamp_vectorized1b <- function(x) {
+    x %>% lapply(function(y) {
+      if (max(y)-min(y) < 1e-5) {
+        {{{{NULL}}}}
+      } else {
+        {{{{(y - min(y))/(max(y)-min(y))}}}}
+      }
+    })
+  }
+  
+  res <- SimilaR_fromTwoFunctions(clamp_vectorized1a, 
+                                  clamp_vectorized1b, returnType = "data.frame", aggregation = "both")
+  
+  expect_true(is.data.frame(res))
+  expect_equal(res[1, 3], 1)
+  expect_equal(res[1, 4], 1)
+  expect_equal(res[1, 5], 1)
+})
+
+test_that("braces-dead code", {
+  f1 <- function(x) {
+    a <- x + 2
+    b <- a - 2
+    b
+  }
+  
+  
+  
+  f2 <- function(x) {
+    a <- x + 2
+    z <- sum(x)^2
+    b <- a - 2
+    b
+  }
+  
+  f3 <- function(x) {
+    a <- x + 2
+    z <- {sum(x)^2}
+    b <- a - 2
+    b
+  }
+  
+  funs <- list(f1, f2, f3)
+  
+  res <- NULL
+  for (i in 1:(length(funs)-1))
+    for (j in (i+1):length(funs))
+    {
+      res <- rbind(res, SimilaR_fromTwoFunctions(funs[[i]], 
+                                                 funs[[j]],
+                                                 functionNames=as.character(c(i,j)),
+                                                 aggregation="both"))
+      
+    }
+  expect_true(is.data.frame(res))
+  expect_equal(sum(res[1:3, 3] >= rep(1, nrow(res))), length(rep(1, nrow(res))))
+  expect_equal(sum(res[1:3, 4] >= rep(1, nrow(res))), length(rep(1, nrow(res))))
+  expect_equal(sum(res[1:3, 5] == rep(1, nrow(res))), length(rep(1, nrow(res))))
+})
+
+
